==> etherx-0.8.tar.gz: etherx-0.8/daemon/netin.c <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  Jabber
 *  Copyright (C) 1998-1999 The Jabber Team http://jabber.org/
 */

#include "etherxd.h"

/* all this thing does is take data from an incoming xmlstream associated with a transport and feed it to it */
void netin_onNode(thread t, xmlnode in, int type)
{
    tstream ts = (tstream)(t->data);
    ehandler eh_tp = (ehandler)(ts->data_aux5);
    ehandler eh_me = (ehandler)(ts->data_aux1);

    jdebug(ZONE,"netin_onNode");

    if(type == XMLSTREAM_NODE)
    {
        manager_deliver(eh_tp, epacket_new(xmlnode_dup(in), eh_tp->host, ts->host, NULL));
        ts->flag_aux1++;
    }
}

void netin_cleanup(void *arg)
{
    thread t = (thread)arg;
    tstream ts = (tstream)(t->data);
    ehandler eh_tp = (ehandler)(ts->data_aux5);
    ehandler eh_me = (ehandler)(ts->data_aux1);

    logger_conn(eh_tp->namespace, ts->host, eh_tp->host, ts->flag_aux1);
    eh_tp->children = ehandler_list_free(eh_tp->children,eh_me);
}

==> etherx-0.9pre3.tar.gz: etherx-0.9pre3/daemon/netin.c <==
/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  Jabber
 *  Copyright (C) 1998-1999 The Jabber Team http://jabber.org/
 */

#include "etherxd.h"

/* all this thing does is take data from an incoming xmlstream associated with a transport and feed it to it */
void netin_onNode(thread t, xmlnode in, int type)
{
    tstream ts = (tstream)(t->data);
    ehandler eh_tp = (ehandler)(ts->data_aux5);
    ehandler eh_me = (ehandler)(ts->data_aux1);

    log_debug(ZONE,"netin_onNode");

    if(type == XMLSTREAM_NODE)
    {
        manager_deliver(eh_tp, epacket_new(xmlnode_dup(in), eh_tp->host, ts->host, NULL));
        ts->flag_aux1++;
    }
}

void netin_cleanup(void *arg)
{
    thread t = (thread)arg;
    tstream ts = (tstream)(t->data);
    ehandler eh_tp = (ehandler)(ts->data_aux5);
    ehandler eh_me = (ehandler)(ts->data_aux1);

    logger_conn(eh_tp->namespace, ts->host, eh_tp->host, ts->flag_aux1);
    eh_tp->children = ehandler_list_free(eh_tp->children,eh_me);
}
